// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
// dash sign in datadisplay-group.com is not accepted by QML syntax
import com.datadisplaygroup.artistaguicomponents 1.0

Rectangle
{

    width: 800
    height: 480
    color: "#06d6f1"

    property int progress: 100

    // SIGNAL_DECLARATIONS:
        signal writeModbusRegistersInt16(int startAddress, string csv); // comma seperated values
        signal readModbusRegistersInt16(int startAddress, int numberOfConsecutiveRegisters);
        signal writeModbusRegistersString(int startAddress, string value, int numberOfConsecutiveRegisters);
        signal readModbusRegistersString(int startAddress, int numberOfConsecutiveRegisters);
        signal useSwappedByteOrderForInt16(bool doSwap);
        signal useSwappedByteOrderForString(bool doSwap);

    // FOLLOWING SIGNALS ARE VALID IN onLoad()
        signal setupRs232(string port, int baudRate, string parity, int dataBits, int stopBits);
        signal setModbusSlaveId(int targetDeviceSlaveId);
        signal setModbusByteTimeout(int timeoutMs);
        signal setModbusResponseTimeout(int timeoutMs);

    // END SIGNAL DECLARATIONS

    function networkPropertyWriteError(propertyName, errorMessage) {}
    function networkPropertyWriteSuccess(propertyName) {}
    function networkPropertyReadError(propertyName, errorMessage) {}
    function networkPropertyReadSuccess(propertyName,value) {}
    function tagWriteError(tagName, errorMessage) {}
    function tagWriteSuccess(tagName) {}
    function tagReadError(tagName, errorMessage) {}
    function tagReadSuccess(tagName, value) {}
    
    signal writeArtistaNetworkProperty(string propertyName, string value);
    signal readArtistaNetworkProperty(string propertyName);
    signal writeArtistaTag(string tagName, string Value);
    signal readArtistaTag(string tagName);
    signal resetArtistaNetworking();

    // FUNCTIONS
    function onLoad()
    {
        setupRs232("/dev/ttyS1", 9600, "none", 8, 1);
        setModbusSlaveId(1);
        setModbusByteTimeout(150);
        setModbusResponseTimeout(900);
		useSwappedByteOrderForString(1);
        writeModbusRegistersInt16(2,153);
        enable_coffee_beans(3);
    }
    function stringReceived(address, value) {}
    function modbusReadError(startAddress, registerCount, errorCode, errorMessage) {}
    function modbusWriteError(startAddress, registerCount, errorCode, errorMessage) {}
    function modbusWriteSuccess(startAddress, registerCount) {}
    function int16Received(address, value)
    {
        switch(address){
            case 4:
                text_temp.text = "Temperature: " + value + " °C";
                break;
            case 5:
                if (value == 1)
                {
                    // Modal Dialog
                    showDialog("Order Processed...",0,0);
                }
                break;
            case 6:
                progress = value;
                break;
        }
    }

    GpioHandler {
        id: m_gpio_handler
    }

    Panel {
        id: m_panel
    }

    Button {
        id: button1
        target: "Order"
        x: 570
        y: 297
        width: 197
        height: 81
        text: "O R D E R "
        buttonName: "orderButton"
        // Notify Order
        onClicked: {
            writeModbusRegistersInt16(0,1);
            text_processing.visible = true;
        }
    }

    Slider {
        id: slider1
        x: 22
        y: 209
        width: 400
        height: 62
        scale: 1
        rotation: 0
        property real value: 255
        property real minimum: 0
        property real maximum: 255
        property int sent_value: value-1

        onValueChanged: send_new_value;

        function send_new_value()
        {
            // avoid double sends
            if (sent_value != Math.round(value))
            {
                writeModbusRegistersInt16(1, Math.round(value));
                sent_value = Math.round(value);
            }
        }
    }

    Text {
        id: text2
        x: 67
        y: 167
        text: qsTr("Hot")
        font.pixelSize: 20
        font.family: "Liberation Sans"
    }

    Image {
        id: image1
        x: 454
        y: 37
        width: 100
        height: 73
        source: "./gfx/coffee_bean.png"
        MouseArea {
            id: mouse_area1
            anchors.fill: parent
            onClicked: {
                writeModbusRegistersInt16(2,255);
                enable_coffee_beans(5);
            }
        }
    }

    Image {
        id: image2
        x: 454
        y: 120
        width: 100
        height: 73
        source: "./gfx/coffee_bean.png"
        MouseArea {
            id: mouse_area2
            anchors.fill: parent
            onClicked: {
                writeModbusRegistersInt16(2,204);
                enable_coffee_beans(4);
            }
        }
    }

    Image {
        id: image3
        x: 454
        y: 204
        width: 100
        height: 73
        source: "./gfx/coffee_bean.png"
        MouseArea {
            id: mouse_area3
            anchors.fill: parent
            onClicked: {
                writeModbusRegistersInt16(2,153);
                enable_coffee_beans(3);
            }
        }
    }

    Image {
        id: image4
        x: 454
        y: 289
        width: 100
        height: 73
        source: "./gfx/coffee_bean.png"
        MouseArea {
            id: mouse_area4
            anchors.fill: parent
            onClicked: {
                writeModbusRegistersInt16(2,102);
                enable_coffee_beans(2);
            }
        }
    }

    Image {
        id: image5
        x: 454
        y: 373
        width: 100
        height: 73
        source: "./gfx/coffee_bean.png"
        MouseArea {
            id: mouse_area5
            anchors.fill: parent
            onClicked: {
                writeModbusRegistersInt16(2,51);
                enable_coffee_beans(1);
            }
        }
    }

    Slider {
        id: slider_fan
        x: 22
        y: 340
        width: 400
        height: 61
        rotation: 0
        scale: 1
        property real value: 255
        property real minimum: 0
        property real maximum: 255
        property int sent_value: value-1

        onValueChanged: send_new_value();

        function send_new_value()
        {
            // avoid double sends
            if (sent_value != Math.round(value))
            {
                writeModbusRegistersInt16(3, Math.round(value));
                sent_value = Math.round(value);
            }
        }
    }

    Text {
        id: text3
        x: 47
        y: 297
        text: qsTr("Cream")
        font.pixelSize: 20
        font.family: "Liberation Sans"
    }

    Text {
        id: text_temp
        x: 588
        y: 228
        text: qsTr("Temperature: 0 °C")
        font.pixelSize: 20
        font.family: "Liberation Sans"
    }

    Text {
        id: text4
        x: 377
        y: 37
        text: qsTr("Strong")
        font.pixelSize: 20
        font.family: "Liberation Sans"
    }

    ModalDialog {
        id:modal_dialog
        x: 0
        y: 0
        anchors.rightMargin: 0
        anchors.bottomMargin: 0
        anchors.leftMargin: 0
        anchors.topMargin: 0
        anchors.fill: parent
        showCancelButton: false;
        dialogTimeoutMs: 5000;
    }

    Image {
        id: image6
        x: 581
        y: 36
        width: 187
        height: 153
        source: "./gfx/cup-of-coffee.png"
    }

    Timer {
        interval:500; running:true; repeat:true;
        // read Temp, order, Progress
        onTriggered: {
            readModbusRegistersInt16(4,1);
            readModbusRegistersInt16(5,1);
            if (text_processing.visible == true)
            {
                text_processing.text += ".";
                // If there is no slave board connected
                // Timeout with the number of dots
                if (text_processing.text == qsTr("Processing Order............................"))
                {
                    showDialog("Order Processed...",0,0);
                }
            }
        }
    }

    Timer
    {
        id: dialogTimer
        interval: 10000; running: false; repeat: false;
        onTriggered: {
            hideDialog();
            text_processing.text = qsTr("Processing Order");
        }
    }

    Text {
        id: text_processing
        x: 22
        y: 430
        width: 281
        height: 24
        color: "#000000"
        text: qsTr("Processing Order")
        visible: false
        styleColor: "#75f108"
        font.bold: false
        font.pixelSize: 20
        font.family: "Liberation Sans"
    }

    function showDialog(text, showOkBtn, showCancelBtn)
    {
        text_processing.visible = false;
        modal_dialog.text = text;
        modal_dialog.showOkButton = showOkBtn;
        modal_dialog.showCancelButton = showCancelBtn;
        modal_dialog.show();
        dialogTimer.running = true;
        //emit signal?
    }

    function hideDialog()
    {
        modal_dialog.hide();
        //emit signal?
    }

    function enable_coffee_beans(btn)
    {
        switch (btn) {
            case 5:
                image1.opacity = 1.0;
                image2.opacity = 1.0;
                image3.opacity = 1.0;
                image4.opacity = 1.0;
                image5.opacity = 1.0;
                break;
            case 4:
                image1.opacity = 0.4;
                image2.opacity = 1.0;
                image3.opacity = 1.0;
                image4.opacity = 1.0;
                image5.opacity = 1.0;
                break;
            case 3:
                image1.opacity = 0.4;
                image2.opacity = 0.4;
                image3.opacity = 1.0;
                image4.opacity = 1.0;
                image5.opacity = 1.0;
                break;
            case 2:
                image1.opacity = 0.4;
                image2.opacity = 0.4;
                image3.opacity = 0.4;
                image4.opacity = 1.0;
                image5.opacity = 1.0;
                break;
            case 1:
                image1.opacity = 0.4;
                image2.opacity = 0.4;
                image3.opacity = 0.4;
                image4.opacity = 0.4;
                image5.opacity = 1.0;
                break;
        }
    }
}


